<?
/* 
 * EDOMI beta (Version 1.60) - Intelligente Steuerung und Visualisierung KNX-basierter Elektro-Installationen.
 * @link http://www.edomi.de 
 * @author Dr. Christian Gärtner <dr.christian.gaertner@googlemail.com> 
 * @copyright 2015,2016,2017 Dr. Christian Gärtner 
 * @license Freeware 
 *
 *     This file and all other files are part of EDOMI.
 *
 *     EDOMI is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 *     Diese und alle anderen Dateien sind Teil von EDOMI.
 *
 *     EDOMI wird in der Hoffnung, dass es nützlich sein wird, aber
 *     OHNE JEDE GEWÄHRLEISTUNG, bereitgestellt; sogar ohne die implizite
 *     Gewährleistung der MARKTFÄHIGKEIT oder EIGNUNG FÜR EINEN BESTIMMTEN ZWECK.
*/ 
?><?
/*
======================================================================================================================================================
ADMIN/MAIN: Initialisierung aller Datenbanken
======================================================================================================================================================
*/


//--------------------------------------------------------------------------------------------------
//Admin-Datenbanken
//--------------------------------------------------------------------------------------------------
function init_DB_Admin() {
/*
	Datenbank erstellen (falls ganz frische Installation, existiert die edomiAdmin noch nicht...)
*/
	sql_call("CREATE DATABASE IF NOT EXISTS edomiAdmin");
	if (!sql_dbExists('edomiAdmin')) {return false;}

/*
	db.project neu erstellen
*/
	sql_call("DROP TABLE IF EXISTS edomiAdmin.project");
	$r=sql_call("CREATE TABLE edomiAdmin.project (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		name VARCHAR(200) DEFAULT NULL,
		createdate datetime DEFAULT NULL,
		savedate datetime DEFAULT NULL,
		livedate datetime DEFAULT NULL,
		edit TINYINT UNSIGNED DEFAULT 0,
		live TINYINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	db.user neu erstellen (die db.id ist fest definiert!)
		id:	1=Admin (typ=0)
			2=Statusseite (typ=1)
			3=Remote-Nutzer (für Fernzugriff) (typ=10)
*/
	sql_call("DROP TABLE IF EXISTS edomiAdmin.user");
	$r=sql_call("CREATE TABLE edomiAdmin.user (
		id BIGINT UNSIGNED DEFAULT NULL,
		typ TINYINT UNSIGNED DEFAULT NULL,
		login VARCHAR(30) DEFAULT NULL,
		pass VARCHAR(30) DEFAULT NULL,
		logindate datetime DEFAULT NULL,
		logoutdate datetime DEFAULT NULL,
		actiondate datetime DEFAULT NULL,
		loginip VARCHAR(45) DEFAULT NULL,
		sid VARCHAR(30) DEFAULT NULL,
		KEY (id),
		KEY (typ),
		KEY (sid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("INSERT INTO edomiAdmin.user (id,typ,login,pass) VALUES
		(1,0,'admin','admin'),
		(2,1,'status','status'),
		(3,10,'remote','remote')
	");
	if (!$r) {return false;}

	return true;
}

//--------------------------------------------------------------------------------------------------
//Projekt-Datenbanken
//--------------------------------------------------------------------------------------------------
function init_DB_Project() {
/*
	Datenbank "edomiProject" ggf. löschen und erstellen
*/
	sql_call("DROP DATABASE IF EXISTS edomiProject");
	sql_call("CREATE DATABASE edomiProject");	
	if (!sql_dbExists('edomiProject')) {return false;}
	
/*
	Projekt-Infos (aktuell nur EDOMI-Version speichern, um beim Öffnen eines Archivs kontrollierte DB-Änderungen vornehmen zu können)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editProjectInfo (
		id BIGINT UNSIGNED DEFAULT NULL,
		edomiversion VARCHAR(30) DEFAULT NULL,
		projectversion VARCHAR(30) DEFAULT NULL,
		text VARCHAR(10000) DEFAULT NULL,
		KEY (id)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("INSERT INTO edomiProject.editProjectInfo (id,edomiversion) VALUES
		(1,'".global_version."')
	");
	if (!$r) {return false;}

/*
	Exportliste
###
	sql_call("DROP TABLE IF EXISTS edomiProject.editProjectExport");
	$r=sql_call("CREATE TABLE edomiProject.editProjectExport (
			id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
			folderid BIGINT UNSIGNED DEFAULT NULL,
			itemid BIGINT UNSIGNED DEFAULT NULL,
			PRIMARY KEY (id),
			KEY (folderid),
			KEY (itemid)
			) ENGINE=MyISAM DEFAULT CHARSET=latin1");

	if (!$r) {return false;}
*/

/*
	Ordner-Struktur (Root)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editRoot (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		allow TINYINT UNSIGNED DEFAULT NULL,
		path VARCHAR(10000) DEFAULT NULL,
		rootid BIGINT UNSIGNED DEFAULT NULL,
		parentid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		namedb VARCHAR(100) DEFAULT NULL,
		link BIGINT UNSIGNED NOT NULL DEFAULT 0,
		linkid BIGINT UNSIGNED DEFAULT NULL,
		sortcolumns VARCHAR(100) DEFAULT NULL,
		sortid TINYINT DEFAULT 0,
		tmp BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (rootid),
		KEY (parentid),
		KEY (path),
		KEY (link),
		KEY (linkid),
		KEY (tmp)
		) ENGINE=MyISAM AUTO_INCREMENT=1000 DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Diagramme
		datefrom/dateto: "" (alles), "now -2 day -10 month", "27.03.2014 23:00:00 -5 year", ...
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editChart (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		titel VARCHAR(100) DEFAULT NULL,
		datefrom VARCHAR(10000) DEFAULT NULL,
		dateto VARCHAR(10000) DEFAULT NULL,
		mode TINYINT DEFAULT 0,
		xunit TINYINT DEFAULT 0,
		xinterval BIGINT DEFAULT NULL,
		ymin FLOAT DEFAULT NULL,
		ymax FLOAT DEFAULT NULL,
		yticks INT UNSIGNED DEFAULT NULL,
		ynice TINYINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Diagramm-Daten (Liste der id's des gewählten KO-Archivs)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editChartList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		archivkoid BIGINT UNSIGNED DEFAULT 0,
		titel VARCHAR(100) DEFAULT NULL,
		charttyp TINYINT UNSIGNED DEFAULT NULL,
		ymin FLOAT DEFAULT NULL,
		ymax FLOAT DEFAULT NULL,
		yticks INT UNSIGNED DEFAULT NULL,
		ynice TINYINT UNSIGNED DEFAULT NULL,
		yshow TINYINT UNSIGNED DEFAULT NULL,
		ygrid1 TINYINT UNSIGNED DEFAULT NULL,
		ygrid2 TINYINT UNSIGNED DEFAULT NULL,
		ygrid3 TINYINT UNSIGNED DEFAULT NULL,
		ystyle TINYINT DEFAULT 0,
		s1 BIGINT UNSIGNED DEFAULT NULL,
		s2 INT DEFAULT NULL,
		s3 INT DEFAULT NULL,
		s4 INT DEFAULT NULL,
		charttyp2 TINYINT UNSIGNED DEFAULT NULL,
		ss1 BIGINT UNSIGNED DEFAULT NULL,
		ss2 INT DEFAULT NULL,
		ss3 INT DEFAULT NULL,
		ss4 INT DEFAULT NULL,
		xinterval BIGINT UNSIGNED DEFAULT NULL,
		yminmax TINYINT UNSIGNED DEFAULT NULL,
		extend1 TINYINT UNSIGNED DEFAULT NULL,
		extend2 TINYINT UNSIGNED DEFAULT NULL,
		yshowvalue TINYINT UNSIGNED DEFAULT NULL,
		yscale TINYINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	eMails
		id: 0..9=reserviert für System-Emails
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editEmail (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		mailaddr VARCHAR(1000) DEFAULT NULL,
		subject VARCHAR(1000) DEFAULT NULL,
		body VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM AUTO_INCREMENT=10 DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Fernzugriff (KOs per HTTP setzen)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editHttpKo (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (gaid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Telefonbuch
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editPhoneBook (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		phone1 VARCHAR(30) DEFAULT NULL,
		phone2 VARCHAR(30) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (phone1),
		KEY (phone2)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");	
	if (!$r) {return false;}

/*	
	Anruftrigger (Anrufe können KOs triggern, sowohl eingehende Anrufe als auch ausgehende Anrufe)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editPhoneCall (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		phoneid1 BIGINT UNSIGNED DEFAULT NULL,
		phoneid2 BIGINT UNSIGNED DEFAULT NULL,
		gaid1 BIGINT UNSIGNED DEFAULT NULL,
		gaid2 BIGINT UNSIGNED DEFAULT NULL,
		gaid3 BIGINT UNSIGNED DEFAULT NULL,
		typ TINYINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (phoneid1),
		KEY (phoneid2)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Anrufarchiv
		hier werden nur die Meta-Infos des Archivs gespeichert (es gibt nur 1 Anrufarchiv)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivPhone (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		keep INT UNSIGNED NOT NULL DEFAULT 0,
		outgaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Anrufarchiv-Daten
		hier werden alle ein- und ausgehenden Anrufe gespeichert
		phone: (Vorwahl+)Rufnummer
		phoneid: db.phoneBook.id (falls Nummer im Telefonbuch vorhanden ist)
		status: reserviert (angenommen, nicht angenommen, usw. - wird noch nicht genutzt)
		typ: 0=Eingehend, 1=Ausgehend
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivPhoneData (
		datetime datetime DEFAULT NULL,
		ms int(11) DEFAULT NULL,
		targetid BIGINT UNSIGNED DEFAULT 0,
		phone VARCHAR(60) DEFAULT NULL,
		phoneid BIGINT UNSIGNED DEFAULT NULL,
		typ TINYINT UNSIGNED DEFAULT 0,
		status TINYINT UNSIGNED DEFAULT 0,
		KEY (datetime,ms),
		KEY (targetid),
		KEY (phone),
		KEY (phoneid),
		KEY (status),
		KEY (typ)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Anwesenheitssimulation
		gaid: diese GA aktiviert/deaktiviert die AWS
		playpointer: >0: zeigt auf die aktuelle editAwsData.id, die gerade dran ist mit Abspielen
					     beim Start (Abspielen) werden alle playpointer auf die "erste" editAwsData.id gesetzt
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editAws (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		recordpointer BIGINT UNSIGNED DEFAULT NULL,
		playpointer BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (recordpointer),
		KEY (playpointer),
		KEY (gaid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");	
	if (!$r) {return false;}

/*
	Anwesenheitssimulation-Daten (die KOs)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editAwsList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		gavalue1 VARCHAR(10000) DEFAULT NULL,
		gavalue2 VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (gaid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Anwesenheitssimulation-Daten (die aufgenommenen Zustände)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editAwsData (
		timestamp BIGINT UNSIGNED DEFAULT NULL,
		targetid BIGINT UNSIGNED DEFAULT 0,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		gavalue VARCHAR(10000) DEFAULT NULL,
		KEY (timestamp),
		KEY (targetid),
		KEY (gaid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");	
	if (!$r) {return false;}
	
/*
	Zeitschaltuhren
		gaid: diese GA aktiviert/deaktiviert die ZSU
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editTimer (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (gaid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");	
	if (!$r) {return false;}
	
/*
	Zeitschaltuhren-Daten (Schaltzeiten)
		targetid: ID der ZSU aus der DB edomiLive.timer
		fixed: feste Schaltzeit aus der Konfiguration (1) oder variable Schaltzeit aus der Visu (0)
		cmdid: Makro-ID (das Makro wird beim Erreichen der Schaltzeit ausgeführt)
		hour: Stunde
		minute: Minute
		day1/day2: Tag von/bis (NULL=k.A.)
		month1/month2: Monat von/bis (NULL=k.A.)
	​​​​​​	​year1/year2: Jahr von/bis (NULL=k.A.)
		d0..d6: Wochentage (Mo..So), 0=deaktiviert, 1=aktiviert
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editTimerData (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		fixed TINYINT UNSIGNED NOT NULL DEFAULT 0,
		cmdid BIGINT UNSIGNED DEFAULT 0,
		hour SMALLINT UNSIGNED DEFAULT NULL,
		minute SMALLINT UNSIGNED DEFAULT NULL,
		day1 SMALLINT UNSIGNED DEFAULT NULL,
		day2 SMALLINT UNSIGNED DEFAULT NULL,
		month1 SMALLINT UNSIGNED DEFAULT NULL,
		month2 SMALLINT UNSIGNED DEFAULT NULL,
		year1 SMALLINT UNSIGNED DEFAULT NULL,
		year2 SMALLINT UNSIGNED DEFAULT NULL,
		mode TINYINT UNSIGNED DEFAULT 0,
		d0 TINYINT UNSIGNED DEFAULT 0,
		d1 TINYINT UNSIGNED DEFAULT 0,
		d2 TINYINT UNSIGNED DEFAULT 0,
		d3 TINYINT UNSIGNED DEFAULT 0,
		d4 TINYINT UNSIGNED DEFAULT 0,
		d5 TINYINT UNSIGNED DEFAULT 0,
		d6 TINYINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (hour),
		KEY (minute),
		KEY (day1),
		KEY (day2),
		KEY (month1),
		KEY (month2),
		KEY (year1),
		KEY (year2),
		KEY (d0),
		KEY (d1),
		KEY (d2),
		KEY (d3),
		KEY (d4),
		KEY (d5),
		KEY (d6)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Zeitschaltuhren-Makro-Liste (für Visualisierungen)
		targetid: ID des Makros
		timerid: ID der ZSU
		sort: Sortierschlüssel
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editTimerMacroList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT NULL,
		timerid BIGINT UNSIGNED DEFAULT NULL,
		sort BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (timerid),
		KEY (sort)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Terminschaltuhren
		gaid: diese GA aktiviert/deaktiviert die TSU
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editAgenda (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (gaid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Terminschaltuhren-Daten (Termine)
		targetid: ID der TSU aus der DB edomiLive.agenda
		fixed: feste Schaltzeit aus der Konfiguration (1) oder variable Schaltzeit aus der Visu (0)
		cmdid: Makro-ID (das Makro wird beim Erreichen des Termins ausgeführt)
		hour: Stunde
		minute: Minute
		date1/date2: Datumsbereich (date2 kann auch leer sein => unendlich)
		step: Intervall
		unit: Intervall-Einheit
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editAgendaData (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		name VARCHAR(100) DEFAULT NULL,
		fixed TINYINT UNSIGNED NOT NULL DEFAULT 0,
		cmdid BIGINT UNSIGNED DEFAULT 0,
		hour SMALLINT UNSIGNED DEFAULT NULL,
		minute SMALLINT UNSIGNED DEFAULT NULL,
		date1 DATE DEFAULT NULL,
		date2 DATE DEFAULT NULL,
		step BIGINT UNSIGNED DEFAULT 0,
		unit SMALLINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (hour),
		KEY (minute),
		KEY (date1),
		KEY (date2),
		KEY (step),
		KEY (unit)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Terminschaltuhren-Makro-Liste (für Visualisierungen)
		targetid: ID des Makros
		agendaid: ID der TSU
		sort: Sortierschlüssel
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editAgendaMacroList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT NULL,
		agendaid BIGINT UNSIGNED DEFAULT NULL,
		sort BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (agendaid),
		KEY (sort)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Sequenzen
		playpointer: >0: zeigt auf die aktuelle editSequenceList.id, die gerade dran ist mit Abspielen
					     beim Start einer Sequenz muss editSequenceList.datetime auf now()+delay gesetzt werden - Server prüft dann nur noch, ob datetime>=jetzt ist und setzt den playpointer entsprechend!
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editSequence (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		datetime datetime DEFAULT NULL,
		ms INT DEFAULT NULL,
		playpointer BIGINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (playpointer)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Sequenzen-Daten
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editSequenceList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		outmode TINYINT UNSIGNED DEFAULT NULL,
		outid BIGINT UNSIGNED DEFAULT NULL,
		outvalue VARCHAR(10000) DEFAULT NULL,
		delay INT UNSIGNED DEFAULT NULL,
		sort BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (outmode),
		KEY (outid),
		KEY (outvalue),
		KEY (sort)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Makros
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editMacro (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Makro-Daten
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editMacroCmdList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		outmode TINYINT UNSIGNED DEFAULT NULL,
		outid BIGINT UNSIGNED DEFAULT NULL,
		outvalue VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (outmode),
		KEY (outid),
		KEY (outvalue)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	IP-Telegramme senden
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editIp (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		url VARCHAR(10000) DEFAULT NULL,
		iptyp TINYINT UNSIGNED DEFAULT NULL,
		httperrlog TINYINT UNSIGNED DEFAULT 1,
		httptimeout INT UNSIGNED DEFAULT 10,
		udpraw TINYINT UNSIGNED DEFAULT 0,
		outgaid BIGINT UNSIGNED DEFAULT NULL,
		outgaid2 BIGINT UNSIGNED DEFAULT NULL,
		data VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	IR-Trans
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editIr (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		data VARCHAR(10000) DEFAULT NULL,
		info VARCHAR(50) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Meldungsarchive
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivMsg (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		keep INT UNSIGNED NOT NULL DEFAULT 0,
		delay BIGINT UNSIGNED NOT NULL DEFAULT 0,
		outgaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Meldungsarchiv-Daten
		hier werden die eigentlichen Daten der Meldungsarchive gespeichert
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivMsgData (
		datetime datetime DEFAULT NULL,
		ms int(11) DEFAULT NULL,
		targetid BIGINT UNSIGNED DEFAULT 0,
		msg VARCHAR(10000) DEFAULT NULL,
		KEY (datetime,ms),
		KEY (targetid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	KO-Archive
		hier werden nur die Meta-Infos der Archive gespeichert (wie editScene)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivKo (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		keep INT UNSIGNED NOT NULL DEFAULT 0,
		delay BIGINT UNSIGNED NOT NULL DEFAULT 0,
		outgaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	KO-Archiv-Daten
		hier werden die eigentlichen Daten der Datenarchive gespeichert
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivKoData (
		datetime datetime DEFAULT NULL,
		ms int(11) DEFAULT NULL,
		targetid BIGINT UNSIGNED DEFAULT 0,
		gavalue VARCHAR(10000) DEFAULT NULL,
		KEY (datetime,ms),
		KEY (targetid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Kameras
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editCam (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		cachets BIGINT UNSIGNED DEFAULT NULL,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		url VARCHAR(10000) DEFAULT NULL,
		mjpeg TINYINT DEFAULT 0,
		dvr TINYINT DEFAULT 0,
		dvrrate INT DEFAULT 5,
		dvrkeep INT DEFAULT 0,
		dvrgaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Kameraarchive
		hier werden nur die Meta-Infos der Archive gespeichert (wie editScene)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivCam (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		camid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		keep INT UNSIGNED NOT NULL DEFAULT 0,
		delay BIGINT UNSIGNED NOT NULL DEFAULT 0,
		outgaid BIGINT UNSIGNED DEFAULT NULL,
		outgaid2 BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Kameraarchiv-Bilddaten
		hier werden die eigentlichen Bilder der Kameraarchive gespeichert
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editArchivCamData (
		datetime datetime DEFAULT NULL,
		ms int(11) DEFAULT NULL,
		targetid BIGINT UNSIGNED DEFAULT 0,
		camid BIGINT UNSIGNED DEFAULT NULL,
		KEY (datetime,ms),
		KEY (targetid),
		KEY (camid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Kameraansichten
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editCamView (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		camid BIGINT UNSIGNED DEFAULT NULL,
		srctyp SMALLINT UNSIGNED DEFAULT 0,
		zoom INT DEFAULT 0,
		a1 INT DEFAULT 0,
		a2 INT DEFAULT 0,
		x INT DEFAULT 0,
		y INT DEFAULT 0,
		dstw INT DEFAULT 0,
		dsth INT DEFAULT 0,
		dsts INT DEFAULT 0,
		srcr INT DEFAULT 0,
		srcd INT DEFAULT 0,
		srcs INT DEFAULT 0,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Szenen
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editScene (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Szenen-Daten
		hier werden die eigentlichen Inhalte der Scenen gespeichert (vgl. LogicCmdList)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editSceneList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		gavalue VARCHAR(10000) DEFAULT NULL,
		learngaid BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*	
	Kommunikationsobjekte (intern und KNX-GAs)
		name: für Editor/Debugging
		folderid: für Editor
		ga(knx): die GA (255/255/255)
		gatyp:
		valuetyp: EIS-Typ (ggf. noch interne Typen => bei internen ist es eigentlich egal, die entsprechende Funktion weiß ja den Typ...)
		value(knx): bei jedem Start leeren! (wird dann entweder vom Bus eingelesen (request), oder bekommt (über den Bus) defaultvalue zugewiesen
		defaultvalue(knx): wird beim Start gesendet! (wenn <> NULL, und initsend=1)
		value(intern): wird entweder mit defaultvalue beim Start überschrieben (s.u.) oder bleibt wie es ist (remanent=1)
		defaultvalue(intern): wird beim Start in Value kopiert (wenn remanent=0)
		initscan(nur knx): GA wird von EDOMI beim Start per REQUEST abgefragt
		initsend(nur knx): defaultvalue der GA wird beim Start auf den Bus gesendet (nur wenn initscan=0)
		requestable(nur knx): 0=nicht abfragbar (GA wird per WRITE gesendet), 1..6: GA kann vom(!) Bus abgefragt werden (die Antwort wird per WRITE oder RESPONSE gesendet)
			Achtung: WRITE/RESPONSE bezieht sich auf jedes(!) Senden dieser GA - nicht nur auf eine Antwort auf einen Read-Request!
		remanent(nur intern): GA ist remanent (wenn = 0: beim Start defaultvalue in value kopieren)
		vmin/vmax: min/max-Bereich für Value
		vstep: Schrittgröße für Value (bei plus/minus-Knöppen)
		vlist: Anzahl der Nachkommastellen (NULL=beliebig, 0=keine, 1=eine, 2=zwei, ...)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editKo (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		name VARCHAR(100) DEFAULT NULL,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		ga VARCHAR(11) DEFAULT NULL,
		gatyp TINYINT UNSIGNED DEFAULT NULL,
		valuetyp INT UNSIGNED NOT NULL DEFAULT 0,
		value VARCHAR(10000) DEFAULT NULL,
		defaultvalue VARCHAR(10000) DEFAULT NULL,
		initscan TINYINT UNSIGNED DEFAULT 0,
		initsend TINYINT UNSIGNED DEFAULT 0,
		requestable TINYINT UNSIGNED DEFAULT 0,
		remanent TINYINT UNSIGNED DEFAULT 0,
		vmin FLOAT DEFAULT NULL,
		vmax FLOAT DEFAULT NULL,
		vstep FLOAT DEFAULT NULL,
		vlist INT UNSIGNED DEFAULT NULL,
		vcsv VARCHAR(1000) DEFAULT NULL,
		text VARCHAR(1000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (ga),
		KEY (gatyp),
		KEY (remanent)
		) ENGINE=MyISAM AUTO_INCREMENT=100 DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Visus
		die Visualisierungen (NICHT die einzelnen Seiten)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisu (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		xsize SMALLINT UNSIGNED DEFAULT 0,
		ysize SMALLINT UNSIGNED DEFAULT 0,
		defaultpageid BIGINT UNSIGNED DEFAULT NULL,
		sspageid BIGINT UNSIGNED DEFAULT NULL,
		sstimeout INT UNSIGNED DEFAULT 0,
		indicolor BIGINT UNSIGNED DEFAULT 0,
		indicolor2 BIGINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visu-User (Accounts)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuUser (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		login VARCHAR(30) DEFAULT NULL,
		pass VARCHAR(30) DEFAULT NULL,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		gaid2 BIGINT UNSIGNED DEFAULT NULL,
		gaid3 BIGINT UNSIGNED DEFAULT NULL,
		touch SMALLINT UNSIGNED DEFAULT 0,
		touchscroll SMALLINT UNSIGNED DEFAULT 0,
		autologout TINYINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (login),
		KEY (pass),
		KEY (gaid),
		KEY (gaid2),
		KEY (gaid3)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visu-User-Liste
		Zuordnungen: User <--> Visus
		Online-Status, Visualarm, etc.
		visuinit: 1=Visu inititalisieren
		visupageid: Visualarm: pageID
		visusoundid: VisuSound: soundID
		visuspeech: Text für Sprachausgabe
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuUserList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT NULL,
		visuid BIGINT UNSIGNED DEFAULT NULL,
		visuinit TINYINT UNSIGNED DEFAULT NULL,
		visupageid BIGINT UNSIGNED DEFAULT NULL,
		visusoundid BIGINT UNSIGNED DEFAULT NULL,
		visuspeech VARCHAR(10000) DEFAULT NULL,
		logindate datetime DEFAULT NULL,
		logoutdate datetime DEFAULT NULL,
		actiondate datetime DEFAULT NULL,
		loginip VARCHAR(45) DEFAULT NULL,
		sid VARCHAR(30) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (visuid),
		KEY (actiondate),
		KEY (sid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visu-Seiten
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuPage (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		visuid BIGINT UNSIGNED DEFAULT NULL,
		includeid BIGINT UNSIGNED NOT NULL DEFAULT 0,
		globalinclude TINYINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		pagetyp TINYINT UNSIGNED DEFAULT 0,
		xpos INT DEFAULT NULL,
		ypos INT DEFAULT NULL,
		xsize INT UNSIGNED DEFAULT NULL,
		ysize INT UNSIGNED DEFAULT NULL,
		autoclose INT UNSIGNED DEFAULT 0,
		bgcolorid BIGINT UNSIGNED DEFAULT 0,
		bgimg BIGINT UNSIGNED DEFAULT NULL,
		xgrid SMALLINT UNSIGNED DEFAULT 1,
		ygrid SMALLINT UNSIGNED DEFAULT 1,
		outlinecolorid BIGINT UNSIGNED DEFAULT 0,
		tmp BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (visuid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visuelemente: Designvorlagen einschließlich Designs (Styles)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuElementDef (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		styletyp TINYINT UNSIGNED DEFAULT 0,
		s1 VARCHAR(500) DEFAULT NULL,
		s2 VARCHAR(500) DEFAULT NULL,
		s3 VARCHAR(500) DEFAULT NULL,
		s4 VARCHAR(500) DEFAULT NULL,
		s5 VARCHAR(500) DEFAULT NULL,
		s6 VARCHAR(500) DEFAULT NULL,
		s7 VARCHAR(500) DEFAULT NULL,
		s8 VARCHAR(500) DEFAULT NULL,
		s9 BIGINT UNSIGNED DEFAULT NULL,
		s10 BIGINT UNSIGNED DEFAULT NULL,
		s11 VARCHAR(10000) DEFAULT NULL,
		s12 VARCHAR(500) DEFAULT NULL,
		s13 BIGINT UNSIGNED DEFAULT NULL,
		s14 VARCHAR(500) DEFAULT NULL,
		s15 BIGINT UNSIGNED DEFAULT NULL,
		s16 TINYINT UNSIGNED DEFAULT NULL,
		s17 TINYINT UNSIGNED DEFAULT NULL,
		s18 TINYINT UNSIGNED DEFAULT NULL,
		s19 VARCHAR(500) DEFAULT NULL,
		s20 VARCHAR(500) DEFAULT NULL,
		s21 VARCHAR(500) DEFAULT NULL,
		s22 BIGINT UNSIGNED DEFAULT NULL,
		s23 VARCHAR(500) DEFAULT NULL,
		s24 VARCHAR(500) DEFAULT NULL,
		s25 VARCHAR(500) DEFAULT NULL,
		s26 VARCHAR(500) DEFAULT NULL,
		s27 BIGINT UNSIGNED DEFAULT NULL,
		s28 BIGINT UNSIGNED DEFAULT NULL,
		s29 BIGINT UNSIGNED DEFAULT NULL,
		s30 BIGINT UNSIGNED DEFAULT NULL,
		s31 VARCHAR(500) DEFAULT NULL,
		s32 TINYINT UNSIGNED DEFAULT NULL,
		s33 VARCHAR(500) DEFAULT NULL,
		s34 VARCHAR(500) DEFAULT NULL,
		s35 VARCHAR(500) DEFAULT NULL,
		s36 VARCHAR(500) DEFAULT NULL,
		s37 BIGINT UNSIGNED DEFAULT NULL,
		s38 TINYINT UNSIGNED DEFAULT NULL,
		s39 BIGINT UNSIGNED DEFAULT NULL,
		s40 VARCHAR(500) DEFAULT NULL,
		s41 VARCHAR(500) DEFAULT NULL,
		s42 BIGINT UNSIGNED DEFAULT NULL,
		s43 BIGINT UNSIGNED DEFAULT NULL,
		s44 BIGINT UNSIGNED DEFAULT NULL,
		s45 BIGINT UNSIGNED DEFAULT NULL,
		s46 BIGINT UNSIGNED DEFAULT NULL,
		s47 BIGINT UNSIGNED DEFAULT NULL,
		s48 VARCHAR(1000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name),
		KEY (styletyp),
		KEY (s1),
		KEY (s2)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visuelemente
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuElement (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		controltyp TINYINT UNSIGNED DEFAULT 0,
		dynstylemode INT UNSIGNED DEFAULT 0,
		visuid BIGINT UNSIGNED DEFAULT NULL,
		pageid BIGINT UNSIGNED DEFAULT NULL,
		gaid BIGINT UNSIGNED DEFAULT NULL,
		galive INT DEFAULT 0,
		gaid2 BIGINT UNSIGNED DEFAULT NULL,
		zindex INT UNSIGNED DEFAULT 0,
		xpos INT DEFAULT NULL,
		ypos INT DEFAULT NULL,
		xsize INT UNSIGNED DEFAULT NULL,
		ysize INT UNSIGNED DEFAULT NULL,
		text VARCHAR(10000) DEFAULT NULL,
		initonly TINYINT UNSIGNED DEFAULT 0,
		var1 VARCHAR(20) DEFAULT NULL,
		var2 VARCHAR(20) DEFAULT NULL,
		var3 VARCHAR(20) DEFAULT NULL,
		var4 VARCHAR(20) DEFAULT NULL,
		var5 VARCHAR(20) DEFAULT NULL,
		var6 VARCHAR(20) DEFAULT NULL,
		var7 VARCHAR(20) DEFAULT NULL,
		var8 VARCHAR(20) DEFAULT NULL,
		var9 VARCHAR(20) DEFAULT NULL,
		var10 VARCHAR(20) DEFAULT NULL,
		gotopageid BIGINT UNSIGNED DEFAULT NULL,
		closepopup TINYINT UNSIGNED DEFAULT 0,
		hascmd TINYINT UNSIGNED DEFAULT 0,
		name VARCHAR(200) DEFAULT NULL,
		groupid BIGINT UNSIGNED NOT NULL DEFAULT 0,
		layer INT UNSIGNED DEFAULT 0,
		tmp BIGINT UNSIGNED DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (controltyp),
		KEY (visuid),
		KEY (pageid),
		KEY (gaid),
		KEY (name),
		KEY (groupid),
		KEY (layer),
		KEY (tmp)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visuelemente: Designs (Styles)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuElementDesign (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED NOT NULL,
		defid BIGINT UNSIGNED DEFAULT NULL,
		styletyp TINYINT UNSIGNED DEFAULT 0,
		s1 VARCHAR(500) DEFAULT NULL,
		s2 VARCHAR(500) DEFAULT NULL,
		s3 VARCHAR(500) DEFAULT NULL,
		s4 VARCHAR(500) DEFAULT NULL,
		s5 VARCHAR(500) DEFAULT NULL,
		s6 VARCHAR(500) DEFAULT NULL,
		s7 VARCHAR(500) DEFAULT NULL,
		s8 VARCHAR(500) DEFAULT NULL,
		s9 BIGINT UNSIGNED DEFAULT NULL,
		s10 BIGINT UNSIGNED DEFAULT NULL,
		s11 VARCHAR(10000) DEFAULT NULL,
		s12 VARCHAR(500) DEFAULT NULL,
		s13 BIGINT UNSIGNED DEFAULT NULL,
		s14 VARCHAR(500) DEFAULT NULL,
		s15 BIGINT UNSIGNED DEFAULT NULL,
		s16 TINYINT UNSIGNED DEFAULT NULL,
		s17 TINYINT UNSIGNED DEFAULT NULL,
		s18 TINYINT UNSIGNED DEFAULT NULL,
		s19 VARCHAR(500) DEFAULT NULL,
		s20 VARCHAR(500) DEFAULT NULL,
		s21 VARCHAR(500) DEFAULT NULL,
		s22 BIGINT UNSIGNED DEFAULT NULL,
		s23 VARCHAR(500) DEFAULT NULL,
		s24 VARCHAR(500) DEFAULT NULL,
		s25 VARCHAR(500) DEFAULT NULL,
		s26 VARCHAR(500) DEFAULT NULL,
		s27 BIGINT UNSIGNED DEFAULT NULL,
		s28 BIGINT UNSIGNED DEFAULT NULL,
		s29 BIGINT UNSIGNED DEFAULT NULL,
		s30 BIGINT UNSIGNED DEFAULT NULL,
		s31 VARCHAR(500) DEFAULT NULL,
		s32 TINYINT UNSIGNED DEFAULT NULL,
		s33 VARCHAR(500) DEFAULT NULL,
		s34 VARCHAR(500) DEFAULT NULL,
		s35 VARCHAR(500) DEFAULT NULL,
		s36 VARCHAR(500) DEFAULT NULL,
		s37 BIGINT UNSIGNED DEFAULT NULL,
		s38 TINYINT UNSIGNED DEFAULT NULL,
		s39 BIGINT UNSIGNED DEFAULT NULL,
		s40 VARCHAR(500) DEFAULT NULL,
		s41 VARCHAR(500) DEFAULT NULL,
		s42 BIGINT UNSIGNED DEFAULT NULL,
		s43 BIGINT UNSIGNED DEFAULT NULL,
		s44 BIGINT UNSIGNED DEFAULT NULL,
		s45 BIGINT UNSIGNED DEFAULT NULL,
		s46 BIGINT UNSIGNED DEFAULT NULL,
		s47 BIGINT UNSIGNED DEFAULT NULL,
		s48 VARCHAR(1000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (defid),
		KEY (styletyp),
		KEY (s1),
		KEY (s2)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Visuelement: Befehle
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuCmdList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		outmode TINYINT UNSIGNED DEFAULT NULL,
		outid BIGINT UNSIGNED DEFAULT NULL,
		outvalue VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (outmode),
		KEY (outid),
		KEY (outvalue)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*	
	Farben: Hintergrund
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuBGcol (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		color VARCHAR(1000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Farben: Vordergrund
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuFGcol (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		color VARCHAR(1000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Animationen
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuAnim (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		keyframes VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Bilder
		xsize/ysize=0: Vektorgrafik (SVG)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuImg (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		xsize INT UNSIGNED DEFAULT NULL,
		ysize INT UNSIGNED DEFAULT NULL,
		suffix VARCHAR(10) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Sounds (mp3)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuSnd (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Fonts
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editVisuFont (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(200) DEFAULT NULL,
		fonttyp TINYINT UNSIGNED DEFAULT 0,
		fontname VARCHAR(200) DEFAULT NULL,
		fontstyle TINYINT UNSIGNED DEFAULT 0,
		fontweight TINYINT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*	
	Logik: Definition der Elements (Bausteine): Wieviele Eingänge/Ausgänge/usw. (nur für Editor interessant - die Logic ist ja in den PHP-Funktionen fest implementiert)
		id: (unique) die ID des Bausteins (also die ID der korrelierenden PHP-Funktion!)
		name: UND-Gatter, Timer, ...
		folderId: Ordner
		defIn: Definition der Eingänge als String: 1#Trigger#0;2#Test#0;...;5#Blabla#"001"; (Eingangs-Nr. # Bezeichnung # Default/Fixwert)
		defOut: Definition der Ausgänge als String: 1#normal;2#sbc;3#Test1;...; (Ausgangs-Nr. # Bezeichnung)
		defVar: Definition der Variablen (aus logicElementVar) als String: 1#0;2#34;3#;4#Hallo; (varid 1 = 0 ; varid 2 =34 ; varid 3 = NULL ; ...)
			WICHTIG: values können ZAHL oder STRING sein, String darf auch leer sein! Zahl: 123.456 / String: hallo
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicElementDef (
		id BIGINT UNSIGNED NOT NULL,
		name VARCHAR(100) DEFAULT NULL,
		title VARCHAR(100) DEFAULT NULL,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		defin BIGINT UNSIGNED DEFAULT 0,
		defout BIGINT UNSIGNED DEFAULT 0,
		defvar BIGINT UNSIGNED DEFAULT 0,
		errcount BIGINT UNSIGNED NOT NULL DEFAULT 0,
		errmsg VARCHAR(10000) DEFAULT NULL,
		exec TINYINT UNSIGNED DEFAULT 0,
		KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicElementDefIn (
		targetid BIGINT UNSIGNED DEFAULT NULL,
		id BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		value VARCHAR(10000) DEFAULT NULL,
		color TINYINT UNSIGNED DEFAULT 0,
		KEY (targetid),
		KEY (id)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicElementDefOut (
		targetid BIGINT UNSIGNED DEFAULT NULL,
		id BIGINT UNSIGNED DEFAULT NULL,
		name VARCHAR(100) DEFAULT NULL,
		KEY (targetid),
		KEY (id)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicElementDefVar (
		targetid BIGINT UNSIGNED DEFAULT NULL,
		id BIGINT UNSIGNED DEFAULT NULL,
		value VARCHAR(10000) DEFAULT NULL,
		KEY (targetid),
		KEY (id)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*	
	Logikseiten
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicPage (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		folderid BIGINT UNSIGNED DEFAULT NULL,
		pagestatus TINYINT UNSIGNED DEFAULT 0,
		name VARCHAR(200) DEFAULT NULL,
		text VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (folderid),
		KEY (name)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Logik: Befehle
		enthält die Befehlsliste eines LogicElements (nur für FunctionId=12000010 - Ausgangsbox)
		ID: unique ID (nur für Verwaltung, nicht wirklich notwendig)
		targetid: Verknüpfung mit dem Element in der DB LogicElement
		outmode: der Befehl (z.B. 0=GA auf Wert an E1 der Box setzen, 1=GA auf outValue setzen, 2=GA mit outValue toggeln, ...)
		outId: Ziel-ID (je nach mode: GA-ID, SzenenID, SequenzID, usw.)
		outvalue: ggf. Wert (z.B. setze GA auf DIESEN Wert, ...)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicCmdList (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		targetid BIGINT UNSIGNED DEFAULT 0,
		outmode TINYINT UNSIGNED DEFAULT NULL,
		outid BIGINT UNSIGNED DEFAULT NULL,
		outvalue VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (targetid),
		KEY (outmode),
		KEY (outid),
		KEY (outvalue)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Logik: Verknüpfungen der Ein/Ausgänge einer Baustein-Instanz (könnte auch logicEingänge heissen... hier werden ja nur die EINGÄNGE "belegt")
		id: ID (unique autoinc) wird u.a. als Ziel eines Ausgangs benötigt
		Element-ID: zeigt auf die Baustein-Instanz in db.logicElement (wenn ein Baustein z.B. mehrere Eingänge hat, muss jeder Eintrag natürlich die selbe Logik-ID haben)
		Eingang: Nummer des Eingangs am Baustein (1=Wert, 2=Timer-Zeit, ...)
		linkTyp: 0=GA (knx oder intern), 1=Logik-Ausgang, 2=Fixwert
		linkID:
			linktyp=0: db.GA.id (Verknüpfte GA (als db.ga.ID) an dieser Eingangs-ID (intern, extern oder Ausgangs-GA))
				=> wenn irgendein Wert remanent sein soll, muss die GA in seiner DB entsprechend gehalten werden!
			linktyp=1: db.logicElement(!).id (Ausgang irgendeiner Baustein-Instanz)
				Ausgang: (nur wenn linktyp=1) Ausgangsnummer der Baustein-Instanz (1=normal, 2=sbc, ...)
			linktyp=2: (null)
				wenn keine GA/Ausgang verknüpft ist, wird value als Fixwert für den entsprechenden Eingang genommen
				wenn eine GA verknüpft ist, wird die GA.Value beim Triggern (durch diese GA) hier rein geschrieben
					hat die GA den Baustein seit dem Start noch nie(!) getriggert, wird value als "Ersatzwert" genommen (bis die GA irgendwann mal triggert)
				wenn ein Ausgang verknüpft ist, wird hier der berechnete Wert des verknüpften Ausgangs rein geschrieben
			Refresh: muss auf 1 gesetzt werden (von Main oder so), wenn ein Telegramm (intern/extern/Ausgang) mit dieser GA empfangen wurde
				=> Baustein wird ggf. neu berechnet, zumindest aber getriggert
				=> und: so kann ermittelt werden, ob eine Flanke am Eingang anliegt (z.B. für Reset eines Zählers)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicLink (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		elementid BIGINT UNSIGNED NOT NULL,
		eingang SMALLINT UNSIGNED NOT NULL,
		linktyp TINYINT UNSIGNED DEFAULT NULL,
		linkid BIGINT UNSIGNED DEFAULT NULL,
		ausgang SMALLINT UNSIGNED DEFAULT NULL,
		refresh TINYINT UNSIGNED NOT NULL DEFAULT 0,
		value VARCHAR(10000) DEFAULT NULL,
		PRIMARY KEY (id),
		KEY (elementid),
		KEY (linktyp),
		KEY (linkid),
		KEY (refresh)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
/*
	Logik: Baustein-Instanz
		repräsentiert genaue 1 Instanz eines Logik-Bausteins (z.B. Gatter) aus db.logicElementDef
		ID: unique ID dieser Instanz (hier zeigt die Verknüfungs-DB drauf)
		functionID: repräsentiert quasi den Namen der PHP-Funktion
		status: 0=Baustein läuft nicht, 1=Baustein läuft
		Nur für Editor:
			pageid: Arbeitsblatt-ID (Ordner usw. sind wieder ne andere DB)
			xpos/ypos: Position auf dem "Arbeitsblatt"
			name: Bemerkung (irgendwas)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicElement (
		id BIGINT UNSIGNED NOT NULL AUTO_INCREMENT,
		functionid BIGINT UNSIGNED NOT NULL,
		pageid BIGINT UNSIGNED DEFAULT NULL,
		xpos INT UNSIGNED DEFAULT NULL,
		ypos INT UNSIGNED DEFAULT NULL,
		name VARCHAR(10000) DEFAULT NULL,
		layer INT UNSIGNED DEFAULT 0,
		PRIMARY KEY (id),
		KEY (functionid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}

/*
	Logik: Variable
		DB für Logik-Variablen zur Laufzeit (Timer, Zählerstände, etc.)
		db.logicElement.id: Zu diesem Logic-Element gehört die Variable
		varID: unique ID dieser Variable (unique nur INNERHALB des Logic-Elements), also quasi der Variablen-Name, z.B. 1=Timer1, 2=Hilfsvariable, 3=Timer2, 4=Zähler...
		Value: Wert der Variable (DateTime ist einfach ein String... PHP muss das also alles managen)
*/
	$r=sql_call("CREATE TABLE IF NOT EXISTS edomiProject.editLogicElementVar (
		elementid BIGINT UNSIGNED NOT NULL,
		varid SMALLINT UNSIGNED NOT NULL,
		value VARCHAR(10000) DEFAULT NULL,
		KEY (elementid),
		KEY (varid)
		) ENGINE=MyISAM DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	
	
	//--------------------------------------------------------------------------------------------------
	//INSERTS
	//--------------------------------------------------------------------------------------------------
	
/*
	Systemordner
		allow (1 Byte):
		 	1	: ### "Dieser Root-Ordner erlaubt nur virtuelle Ordner (in direkter Instanz)"
			2	: Erstellen von Elementen in diesem Root-Ordner erlauben
			4	: Erstellen von Ordnern in diesem Root-Ordner erlauben
			8	: Bearbeiten (bzw. Umbenennen bei Ordnern) von Elementen/Ordnern in diesem Ordner erlauben
			16	: Copy/Paste von Elementen/Ordnern in diesem Ordner erlauben
			32	: Duplizieren von Elementen/Ordnern in diesem Ordner erlauben
			64	: Löschen von Elementen/Ordnern in diesem Ordner erlauben
			128	: (Reserve) ### Export erlauben?
*/
	$r=sql_call("INSERT INTO edomiProject.editRoot (id,allow,path,rootid,parentid,name,namedb,link,linkid,sortcolumns,sortid) VALUES
		(10,	0,		'/', 		10,0, 		'Logik', NULL, 0, NULL,NULL,0),
		(11,	94,		'/10/',		11,10, 		'Logikseiten', 'editLogicPage', 0, NULL,'id/ID,name/Name',1),
		(12,	8,		'/10/',		12,10, 		'Logikbausteine', 'editLogicElementDef', 0, NULL,'id/ID,name/Name',1),
		(13,	8,		'/10/12/', 	13,12, 		'Grundfunktionen & Auslöser (13)', 'editLogicElementDef', 0, NULL,NULL,0),
		(14,	8, 		'/10/12/', 	14,12, 		'Gatter & Logik (14)', 'editLogicElementDef', 0, NULL,NULL,0),
		(15,	8, 		'/10/12/', 	15,12, 		'Mathematik, Vergleicher & Filter (15)', 'editLogicElementDef', 0, NULL,NULL,0),
		(16,	8,		'/10/12/', 	16,12, 		'Timer & Zeitfunktionen (16)', 'editLogicElementDef', 0, NULL,NULL,0),
		(17,	8,		'/10/12/', 	17,12, 		'Funktionale Einheiten (17)', 'editLogicElementDef', 0, NULL,NULL,0),
		(18,	8,		'/10/12/', 	18,12, 		'Sonstige (18)', 'editLogicElementDef', 0, NULL,NULL,0),
		(19,	94,		'/10/12/', 	19,12,	 	'Eigene Logikbausteine (19)', 'editLogicElementDef', 0, NULL,NULL,0),
		(20,	0,		'/', 		20,0, 		'Visualisierung', NULL, 0, NULL,NULL,0),
		(21,	106,	'/20/', 	21,20, 		'Visualisierungen', 'editVisu', 0, NULL,'id/ID,name/Name',1),
		(22,	127,	'/20/', 	22,20, 		'Visuseiten', 'editVisuPage', 0, NULL,'id/ID,name/Name',1),
		(23,	126,	'/20/', 	23,20, 		'Visuaccounts', 'editVisuUser', 0, NULL,'id/ID,login/Login',1),
		(24,	126,	'/20/', 	24,20, 		'Designvorlagen', 'editVisuElementDef', 0, NULL,'id/ID,name/Name',1),
		(25,	126,	'/20/', 	25,20, 		'Farben (Hintergrund)', 'editVisuBGcol', 0, NULL,'id/ID,name/Name',1),
		(26,	126,	'/20/', 	26,20, 		'Farben (Vordergrund)', 'editVisuFGcol', 0, NULL,'id/ID,name/Name',1),
		(27,	126,	'/20/', 	27,20, 		'Animationen', 'editVisuAnim', 0, NULL,'id/ID,name/Name',1),
		(28,	94,		'/20/', 	28,20, 		'Bilder', 'editVisuImg', 0, NULL,'id/ID,name/Name',1),
		(29,	94,		'/20/', 	29,20, 		'Töne', 'editVisuSnd', 0, NULL,'id/ID,name/Name',1),
		(30,	0,		'/', 		30,0, 		'Kommunikationsobjekte', 'editKo', 0, NULL,NULL,0),
		(31,	126,	'/30/', 	31,30, 		'Interne KOs', 'editKo', 0, NULL,'id/ID,name/Name',1),
		(32,	94,		'/30/', 	32,30, 		'KNX-Gruppenadressen', 'editKo', 0, NULL,'id/ID,name/Name,ga/GA',1),
		(33,	8,		'/30/', 	33,30, 		'System KOs', 'editKo', 0, NULL,'id/ID,name/Name',1),
		(40,	126,	'/', 		40,0, 		'Szenen', 'editScene', 0, NULL,'id/ID,name/Name',1),
		(50,	126,	'/', 		50,0, 		'Datenarchive', 'editArchivKo', 0, NULL,'id/ID,name/Name',1),
		(60,	126,	'/', 		60,0,		'Meldungsarchive', 'editArchivMsg', 0, NULL,'id/ID,name/Name',1),
		(70,	126,	'/', 		70,0, 		'HTTP/UDP/SHELL', 'editIp', 0, NULL,'id/ID,name/Name',1),
		(75,	126,	'/', 		75,0,		'IR-Befehle', 'editIr', 0, NULL,'id/ID,name/Name',1),
		(80,	0,		'/', 		80,0, 		'Kameras', NULL, 0, NULL,NULL,0),
		(81,	126,	'/80/', 	81,80,		'Kameraeinstellungen', 'editCam', 0, NULL,'id/ID,name/Name',1),
		(82,	126,	'/80/', 	82,80,		'Kameraarchive', 'editArchivCam', 0, NULL,'id/ID,name/Name',1),
		(83,	126,	'/80/', 	83,80,		'Kameraansichten', 'editCamView', 0, NULL,'id/ID,name/Name',1),
		(90,	126,	'/', 		90,0,		'Sequenzen', 'editSequence', 0, NULL,'id/ID,name/Name',1),
		(95,	126,	'/', 		95,0,		'Makros', 'editMacro', 0, NULL,'id/ID,name/Name',1),
		(100,	126,	'/', 		100,0,		'Zeitschaltuhren', 'editTimer', 0, NULL,'id/ID,name/Name',1),
		(101,	126,	'/', 		101,0,		'Terminschaltuhren', 'editAgenda', 0, NULL,'id/ID,name/Name',1),
		(110,	126,	'/', 		110,0,		'Anwesenheitssimulationen', 'editAws', 0, NULL,'id/ID,name/Name',1),
		(120,	0,		'/', 		120,0,		'Emails', 'editEmail', 0, NULL,NULL,0),
		(121,	126,	'/120/', 	121,120,	'Eigene Emails', 'editEmail', 0, NULL,'id/ID,name/Name',1),
		(122,	8,		'/120/', 	122,120,	'System-Emails', 'editEmail', 0, NULL,'id/ID,name/Name',1),
		(124,	0,		'/', 		124,0,		'Telefon', NULL, 0, NULL,NULL,0),
		(125,	94,		'/124/', 	125,124,	'Telefonbuch', 'editPhoneBook', 0, NULL,'id/ID,name/Name',1),
		(126,	126,	'/124/', 	126,124,	'Anruftrigger', 'editPhoneCall', 0, NULL,'id/ID,name/Name',1),
		(127,	126,	'/124/', 	127,124,	'Anrufarchive', 'editArchivPhone', 0, NULL,'id/ID,name/Name',1),
		(130,	126,	'/20/', 	130,20,		'Diagramme', 'editChart', 0, NULL,'id/ID,name/Name',1),
		(140,	94,		'/', 		140,0,		'Fernzugriff', 'editHttpKo', 0, NULL,'id/ID,name/Name',1),
		(150,	94,		'/20/', 	150,20,		'Schriftarten', 'editVisuFont', 0, NULL,'id/ID,name/Name',1)
	");	
	if (!$r) {return false;}
	
/*
	System-KOs
		id=1: Version: beim Start wird die EDOMI-Version gesetzt
		id=2: Systemstart: 0=EDOMI pausiert/Initphase, 1=EDOMI gestartet (normaler Betrieb), 2=EDOMI wird beendet
		id=3: Server-IP (WAN): wird beim Start und dann alle 60 Minuten ermittelt und BEI ÄNDERUNG(!) hier gespeichert
		id=4: Systemdatum: aktuelles Systemdatum im Format "dd.mm.YYYY" (wird beim Start und dann bei jedem Tageswechsel (ca. 00:00:00 Uhr) gesetzt)
		id=5: Systemzeit: aktuelle Systemzeit im Format "hh:mm:ss" (wird beim Start und dann jede Sekunde gesetzt)
		id=6: GA/KO-Monitor (remanent): 0=aus, 1=nur KNX, 2=nur Intern, 3=Knx und Intern
		id=7: CPU-Warnung: 0=keine, 1=CPU-Last der letzten Minute (>99%) - wird wieder auf 0 gesetzt wenn <90%
		id=8: RAM-Warnung: 0=keine, 1=wenig freies RAM (>90% belegt) - wird wieder auf 0 gesetzt wenn <80%
		id=9: HDD-Warnung: 0=keine, 1=wenig freie HDD-Kapazität (>90% belegt) - wird wieder auf 0 gesetzt wenn <80%
		id=10: ERR-Warnung: 0=keine, 1=Anzahl der Fehler (einschl. "ungeplanter Neustart")
*/
	$r=sql_call("INSERT INTO edomiProject.editKo (id,name,folderid,ga,gatyp,valuetyp,value,defaultvalue,initscan,initsend,requestable,remanent,vmin,vmax,vstep,vlist) VALUES
		(1, 'Version', 33, '1', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(2, 'Systemstart', 33, '2', 2, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(3, 'Server-IP', 33, '3', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(4, 'Systemdatum', 33, '4', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(5, 'Systemzeit', 33, '5', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(6, 'GA/KO-Monitor', 33, '6', 2, 0, NULL, 3, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(7, 'CPU-Warnung', 33, '7', 2, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(8, 'RAM-Warnung', 33, '8', 2, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(9, 'HDD-Warnung', 33, '9', 2, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(10, 'ERROR-Warnung', 33, '10', 2, 0, 0, 0, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(11, 'Zeitumstellung', 33, '11', 2, 0, NULL, NULL, 0, 0, 0, 1, NULL, NULL, NULL, NULL),
		(12, 'EDOMI-Update', 33, '12', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(15, 'Anrufmonitor: Rohdaten', 33, '15', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(17, 'Trigger: Jährlich 00:00:00', 33, '17', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(18, 'Trigger: Monatlich 00:00:00', 33, '18', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(19, 'Trigger: Wöchentlich (Montags) 00:00:00', 33, '19', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(20, 'Trigger: Täglich 00:00:00', 33, '20', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(21, 'Trigger: Stündlich (00..23):00:00', 33, '21', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(22, 'Trigger: Halbstündlich --:(00/30):00', 33, '22', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(23, 'Trigger: Viertelstündlich --:(00/15/30/45):00', 33, '23', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(24, 'Trigger: Zehnminütlich --:(00/10/20/.../50):00', 33, '24', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(25, 'Trigger: Fünfminütlich --:(00/05/10/15/../55):00', 33, '25', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL),
		(26, 'Trigger: Minütlich --:(00/01/02/03/../59):00', 33, '26', 2, 0, NULL, NULL, 0, 0, 0, 0, NULL, NULL, NULL, NULL)
	");
	if (!$r) {return false;}
	
/*
	System-eMails
		id=1: Warnung: Unerwarteter Reboot
		id=2: Warnung: CPU/RAM/HDD
		id=3..9: reserviert für weitere System-Emails (User-Emails beginnen erst bei ID=10)
*/
	$r=sql_call("INSERT INTO edomiProject.editEmail (id,folderid,name,mailaddr,subject,body) VALUES
		(1, 122, 'Warnung: Unerwarteter Reboot', '', 'WARNUNG: EDOMI', 'EDOMI wurde unerwartet rebooted! Die Ursache könnte ein Stromausfall oder ein Absturz gewesen sein. Bitte Log-Dateien überprüfen!'),
		(2, 122, 'Warnung: CPU/RAM/HDD', '', 'WARNUNG: EDOMI', 'Probleme bei CPU-Last, RAM- oder HDD-Kapazität erkannt! Bitte schnellstens überprüfen.')
	");
	if (!$r) {return false;}

/*
	Visu-Beispielfarben: Hintergrund
*/
	$r=sql_call("INSERT INTO edomiProject.editVisuBGcol (folderid,name,color) VALUES
		(25, 'Transparent',						'transparent'),
		(25, 'Schwarz',							'#000000'),
		(25, 'Grau',							'#808080'),
		(25, 'Weiss',							'#ffffff'),
		(25, 'Schwarz (halbtransparent)',		'rgba(0,0,0,0.5)'),
		(25, 'Weiss (halbtransparent)',			'rgba(255,255,255,0.5)'),
		(25, 'schwarz..weiss (KO-gesteuert)',	'rgb({#},{#},{#})'),
		(25, 'Blauer Himmel (Verlauf)',			'-webkit-linear-gradient(top, #80aaff 0%, #eeeeff 100%)'),
		(25, 'Bargraf 0..100 Prozent (Verlauf)','-webkit-linear-gradient(left,#80e000 0%,#80e000 {#}%,#343434 {#}%,#343434 100%)')
	");
	if (!$r) {return false;}

/*
	Visu-Beispielfarben: Vordergrund
*/
	$r=sql_call("INSERT INTO edomiProject.editVisuFGcol (folderid,name,color) VALUES
		(26, 'Transparent',						'transparent'),
		(26, 'Schwarz',							'#000000'),
		(26, 'Grau',							'#808080'),
		(26, 'Weiss',							'#ffffff'),
		(26, 'Schwarz (halbtransparent)',		'rgba(0,0,0,0.5)'),
		(26, 'Weiss (halbtransparent)',			'rgba(255,255,255,0.5)'),
		(26, 'schwarz..weiss (KO-gesteuert)',	'rgb({#},{#},{#})')
	");
	if (!$r) {return false;}

/*
	Visu-Beispielanimationen
*/
	$r=sql_call("INSERT INTO edomiProject.editVisuAnim (folderid,name,keyframes) VALUES
		(27, 'Blinken',		'0% {opacity:1;}".chr(10)."49% {opacity:1;}".chr(10)."50% {opacity:0;}".chr(10)."99% {opacity:0;}".chr(10)."100% {opacity:1;}'),
		(27, 'Pulsieren',	'0% {opacity:1;}".chr(10)."50% {opacity:0;}".chr(10)."100% {opacity:1;}'),
		(27, 'Pumpen',		'0% {-webkit-transform: scale(1);}".chr(10)."50% {-webkit-transform: scale(0.75);}".chr(10)."100% {-webkit-transform: scale(1);}'),
		(27, 'Rotieren',	'0% {-webkit-transform: rotate(0deg);}".chr(10)."100% {-webkit-transform: rotate(360deg);}')
	");
	if (!$r) {return false;}

	return true;
}

//--------------------------------------------------------------------------------------------------
//Live-Datenbanken
//--------------------------------------------------------------------------------------------------
function init_DB_Live() {
/*
	Datenbank erstellen (falls ganz frische Installation, existiert die edomiLive noch nicht...)
*/
	sql_call("CREATE DATABASE IF NOT EXISTS edomiLive");
	if (!sql_dbExists('edomiLive')) {return false;}

/*
	db.sysInfo erstellen und füllen (bei jedem Start von edomi)
		ID 1 (aktueller Server-Status):
			0=beendet (bzw. wird die DB garnicht existieren)
			-1=wird gerade beendet
			-2=Pausiert, d.h. wartet auf Startbefehl (oder auf ein Projekt, falls noch keins hochgeladen wurde)
			-3=Projektaktivierung wird durchgeführt
			1=Initialisierung
			2=Bereit (Normalzustand)
		
		ID 2 (Server-Status setzen):
			0=(nichts)
		
			10=Pausieren (Neustart und warten auf 11) - es wird IMMER ein Neustart gemacht, auch wenn edomi bereits Pausiert ist!
			11=Starten (wenn Pausiert)
			12=Neustart und durchstarten
			13=Reboot und durchstarten
	
			14=Neustart, Projektaktivierung und Pausieren
			15=Neustart, Live-Daten löschen, Projektaktivierung und Pausieren
	
			21=Beenden, Restore einspielen, Reboot
			22=Beenden und zur Shell
			23=Beenden und Shutdown
			24=Beenden, Update installieren, Reboot
		
			31=Beenden, alle Livedaten löschen, Neustart
			32=Beenden, alle Serverdaten löschen, Neustart
			33=Beenden, alle Daten löschen (Werkseinstellungen), Neustart
		
		ID 3 (Absturz/Stromausfall/etc.):
			0=alles ok
			1=es gab einen Absturz, Stromausfall, oder eine andere Art des ungeplanten Neustarts
	
		ID 4 (FatalError in einem LBS):
			0=alles ok
			1..oo=es gab einen FatalError im LBS mit dieser ID (z.B. 19000001 = LBS_19000001)
*/
	sql_call("DROP TABLE IF EXISTS edomiLive.RAMsysInfo");
	$r=sql_call("CREATE TABLE edomiLive.RAMsysInfo (
		id INT UNSIGNED NOT NULL,
		value INT NOT NULL,
		KEY (id)
		) ENGINE=MEMORY DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("INSERT INTO edomiLive.RAMsysInfo (id,value) VALUES
		(1,0),
		(2,0),
		(3,0),
		(4,0)
	");
	if (!$r) {return false;}

/*
	db.sysProc erstellen und füllen (bei jedem Start von edomi)
		Id 1: proc_main.php
		
			[0]=Startdatum (EDOMI wurde zu diesem DateTime gestartet - also nach der Init-Phase usw.!)
			[1]=PID von proc_main.php (wird von getEdomiStatus() benötigt)
		
			[19]=Status von proc_main.php:
					(ungenutzt)
		
		Id 2: proc_sysinfo.php
			[0]=CPU-Last in %
			[1]=RAM belegt(!) in %
			[2]=HDD belegt(!) in %
			[3]=Systemlast
			[4]
			[5]
			[6]=Anzahl der PHP-Prozesse
			[7]=Anzahl der HTTPD-Prozesse (Apache)
			[8]=Anzahl der DB-Tables (###)
			[10..18]=wie 0..8, aber als Peaks (seit Neustart)
		
			[19]=Status von proc_sysinfo.php:
					0=läuft nicht
					2=läuft
		
		Id 3: proc_knx.php
			[0]=Anzahl der aktuellen Telegramme (KNX) in der Write-Queue (Read-Queue wird von serverLogic.php ermittelt)
			[1]=Gesamtanzahl "unbekannte Nachrichten" (empfangene Nachrichten vom IP-Router, die das Gateway nicht einordnen kann)
			[2]=Gesamtanzahl Read: unbekannte GAs (also GAs, die EDOMI nicht kennt)
			[3]=Gesamtanzahl Write = Tx
			[4]=Gesamtanzahl Read (IP-Router / lokal)
			[5]=Gesamtanzahl Read = Rx (KNX)
			[6]=Gesamtanzahl Read/Write-relevante Fehler (ohne [7])
			[7]=Gesamtanzahl Verbindungsrelevante Fehler,z.B. Open-Fehler, Heartbeat-Timeout, etc. (ohne [6])
			[8]=Gesamtanzahl Verbindungsversuche (normal wäre 1)
			[9]=Verbindungsstatus: 0=disconnected, 1=connected
			[10]=wie [0], aber als Peak (seit Neustart)
			[11]=
			[12]=
			[13]=Telegrammrate (letzten 5s) Write = Tx
			[14]=
			[15]=Telegrammrate (letzten 5s) Read = Rx (KNX)
			[16]=
			[17]=
			[18]=
		
			[19]=Status von proc_knx.php:
					0=läuft nicht
					1=bereit (Prozess ist gestartet, verrichtet aber noch nicht seinen Dienst)
					2=läuft
		
		Id 4: proc_logic.php
			[0]=Anzahl der arbeitenden Logikbausteine, also alle aktuell getriggerten (ohne [4])
			[2]=Anzahl der aktuellen Telegramme (KNX oder intern) in der Read-Queue
			[3]=(frei)
			[4]=Anzahl der laufenden Logikbausteine, z.B. Timer
			[5]=Anzahl der Einträge in der EXEC-Queue
			[6]=Anzahl der laufenden EXEC-Scripte
		
			[1]=Anzahl der Logikbausteine, die korrekt initialisiert wurden (gehört zu [11])
			[11]=Anzahl der Logikbausteine, die zu initialisieren sind (gehört zu [1])
		
			[10,12,13,14,15,16]=wie 0,2,3,4,5,6 aber als Peaks (seit Neustart)
		
			[19]=Status von proc_logic.php:
					0=läuft nicht
					1=bereit (Logic ist deaktiviert (Initialisierungsphase in serverMain.php), d.h. nur Telegramme empfangen und in db.(RAM)ko schreiben)
					2=läuft (Logic ist aktiviert (normaler Zustand))
					3=läuft (Logic ist deaktiviert (Initialisierung der Bausteine))
					4=wird beendet (Logic wird deaktiviert)
		
		Id 5: proc_queue.php
			[0]=Anzahl der aktuellen Befehle mit Status=0 (warten auf Start) in der Queue
			[1]=Anzahl der aktuellen Befehle mit Status=1 (laufen gerade) in der Queue
			[10..18]=wie 0..9, aber als Peaks (seit Neustart)
		
			[19]=Status von proc_queue.php:
					0=läuft nicht
					1=bereit (Prozess ist gestartet, verrichtet aber noch nicht seinen Dienst)
					2=läuft
					Hinweis: der Status wird beim Start von EDOMI in dieser Reihenfolge verändert:
						- während des Wartens auf Start/Projektaktivierung ist der Status=2 (damit in dieser Phase Queue-Befehle abgearbeitet werden können)
						- bei der anschließenden Initialisierung ist der Status=1 (quasi "Pause")
						- und schließlich beim echten Start ist der Status=2 (Queue-Befehle ganz normal abarbeiten)
		
		Id 6: proc_phone.php
			[0]=Status (1=Connected, 0=Disconnected)
			[1]=Gesamtanzahl der eingehenden Anrufe
			[2]=Gesamtanzahl der ausgehenden Anrufe
		
			[19]=Status von proc_phone.php:
					0=läuft nicht
					1=bereit (Prozess ist gestartet, verrichtet aber noch nicht seinen Dienst)
					2=läuft
		
		Id 7: proc_visu.php
			[0]=Status (1=Connected, 0=Disconnected)
			[1]=Anzahl der aktuell verbundenen Clients (=Online)
			[2]=Refresh-Rate (pro Sekunde) über alle Clients (Anzahl der Aktualisierungen pro Sekunde, unabhängig von der Anzahl der Items)
			[3]=Item-Rate (pro Sekunde) über alle Clients (Anzahl der Items, die pro Sekunde aktualisiert werden)
			[4]=Trigger-Rate (pro Sekunde) über alle Clients (Anzahl der "Klicks" eines Nutzers (KO-Value/CMD-Liste), jedoch ohne Seitenwechsel)
			[5]=Page-Rate (pro Sekunde) über alle Clients (Anzahl der Seitenaufrufe/Seitenwechsel)
			[6]=Send-Rate (kb/s) über alle Clients (kb/s Server->Client)
			[7]=Receive-Rate (kb/s) über alle Clients (kb/s Client->Server)
			
			[11..17]=Peaks ab Start
		
			[19]=Status von proc_visu.php:
					0=läuft nicht
					1=bereit (Prozess ist gestartet, verrichtet aber noch nicht seinen Dienst - oder es gibt keine Visus)
					2=läuft
		
		Id 8: proc_dvr.php (und proc_dvrcam.php)
			[0]=Status: 1=Ok, 0=keine Aufnahme möglich (z.B. wenn global_dvrMountcheck fehlschlägt)
			[1]=Anzahl der zur Aufnahme aktivierten Kameras (unabhängig vom tatsächlichen Aufnahmestatus per KO)
			[2]=Anzahl der aktuell aufnehmenden Kameras (abhängig vom tatsächlichen Aufnahmestatus per KO)
			[3]=Anzahl der aufgenommenen Frames seit Start und pro Stunde(!)
			[4]=Anzahl der fehlerhaften Kameras (z.B. Speicher voll, Grabben fehlgeschlagen, etc.)
			[5]=Gesamtanzahl der fehlerhaften Frames seit Start (Problem beim Grabben oder Speichern)
			[6]=HDD belegt(!) in % (Zielverzeichnis)

			[19]=Status von proc_dvr.php:
					0=läuft nicht
					1=bereit (Prozess ist gestartet, verrichtet aber noch nicht seinen Dienst)
					2=läuft
		
		Id 9: Prozess-Steuerung: proc_main.php steuert hiermit die anderen Prozesse (diese greifen nur lesend zu)
			[0]
			[1]
			[2]=proc_sysinfo.php:	1=Beenden (ist per default aktiviert, bzw. steuert sich selbst)
			[3]=proc_knx.php: 		1=Beenden (ist per default aktiviert, bzw. steuert sich selbst)
			[4]=proc_logic.php: 	1=Beenden (ist per default aktiviert, bzw. steuert sich selbst über sysKO[2])
			[5]=proc_queue.php:		0=Warten, 1=Beenden, 2=Aktivieren (Normalzustand)
			[6]=proc_phone.php:		0=Warten, 1=Beenden, 2=Aktivieren (Normalzustand) Achtung: Nachdem der Phonemonitor aktiviert wurde (2), kann er nur noch beendet werden (1), aber NICHT pausiert (0)!
			[7]=proc_visu.php:		1=Beenden (ist per default aktiviert, bzw. steuert sich selbst)
			[8]=reserviert für "proc_8.php"
			[9..19]=dto.
*/
	sql_call("DROP TABLE IF EXISTS edomiLive.RAMsysProc");
	$r=sql_call("CREATE TABLE edomiLive.RAMsysProc (
		id INT UNSIGNED NOT NULL,
		s0 VARCHAR(20) DEFAULT NULL,
		s1 VARCHAR(20) DEFAULT NULL,
		s2 VARCHAR(20) DEFAULT NULL,
		s3 VARCHAR(20) DEFAULT NULL,
		s4 VARCHAR(20) DEFAULT NULL,
		s5 VARCHAR(20) DEFAULT NULL,
		s6 VARCHAR(20) DEFAULT NULL,
		s7 VARCHAR(20) DEFAULT NULL,
		s8 VARCHAR(20) DEFAULT NULL,
		s9 VARCHAR(20) DEFAULT NULL,
		s10 VARCHAR(20) DEFAULT NULL,
		s11 VARCHAR(20) DEFAULT NULL,
		s12 VARCHAR(20) DEFAULT NULL,
		s13 VARCHAR(20) DEFAULT NULL,
		s14 VARCHAR(20) DEFAULT NULL,
		s15 VARCHAR(20) DEFAULT NULL,
		s16 VARCHAR(20) DEFAULT NULL,
		s17 VARCHAR(20) DEFAULT NULL,
		s18 VARCHAR(20) DEFAULT NULL,
		s19 VARCHAR(20) DEFAULT NULL,
		s20 VARCHAR(20) DEFAULT NULL,
		KEY (id)
		) ENGINE=MEMORY DEFAULT CHARSET=latin1
	");
	if (!$r) {return false;}
	$r=sql_call("INSERT INTO edomiLive.RAMsysProc (id) VALUES (1),(2),(3),(4),(5),(6),(7),(8),(9)");
	if (!$r) {return false;}

/*
	db.RAMlivemon erstellen und füllen (bei jedem Start von edomi)
*/
	sql_call("DROP TABLE IF EXISTS edomiLive.RAMlivemon");
	$r=sql_call("CREATE TABLE edomiLive.RAMlivemon (
			ts VARCHAR(20) DEFAULT NULL,
			datetime datetime DEFAULT NULL,
			ms int(11) DEFAULT NULL,
			pa varchar(11) DEFAULT NULL,
			gamode TINYINT DEFAULT NULL,
			gatyp INT UNSIGNED DEFAULT NULL,
			gaid BIGINT UNSIGNED DEFAULT NULL,
			ga varchar(11) DEFAULT NULL,
			ganame varchar(200) DEFAULT NULL,
			gavalue varchar(200) DEFAULT NULL,
			KEY (ts),
			KEY (datetime)
			) ENGINE=MEMORY DEFAULT CHARSET=latin1");
	if (!$r) {return false;}
	$tmp=global_koMonMaxCount;
	if ($tmp<1) {$tmp=1;} else if ($tmp>1000) {$tmp=1000;}
	for ($t=0;$t<$tmp;$t++) {
		$r=sql_call("INSERT INTO edomiLive.RAMlivemon (ts) VALUES ('00000000000000000000')");
	}
	if (!$r) {return false;}

/*
	db.logicExecQueue erstellen (bei jedem Start von edomi)
*/
	sql_call("DROP TABLE IF EXISTS edomiLive.logicExecQueue");
	$r=sql_call("CREATE TABLE edomiLive.logicExecQueue (
			ts VARCHAR(20) DEFAULT NULL,
			elementid BIGINT UNSIGNED DEFAULT NULL,
			inputid SMALLINT UNSIGNED NOT NULL,
			refresh TINYINT UNSIGNED NOT NULL DEFAULT 0,
			value VARCHAR(10000) DEFAULT NULL,
			KEY (ts),
			KEY (elementid),
			KEY (inputid)
			) ENGINE=MyISAM DEFAULT CHARSET=latin1");
	if (!$r) {return false;}

	return true;
}
?>
